@@ -36,8 +36,8 @@ ALIASES = {
     "g": generate
 }
 
-def generate_model(projectName):
-    click.echo('model generated ' + projectName)
+def generate_project(projectName):
+    click.echo('project generated ' + projectName)
     create_project(projectName)
 
 def create_project(projectName):
@@ -45,6 +45,7 @@ def create_project(projectName):
     create_pipeline_file(projectName, 'preprocessor')
     create_pipeline_file(projectName, 'postprocessor')
     create_pipeline_file(projectName, 'labelizer')
+    create_pipeline_file(projectName, 'pipeline')
 
 def create_folder(projectName):
     global directory
@@ -55,11 +56,14 @@ def create_folder(projectName):
 def create_pipeline_file(projectName, pipelineType):
     with open(os.path.join(__location__, 'cli/' + pipelineType + '_template.py'), 'r') as file:
         data = file.read()
+        projectName = projectName.replace('-', '_')
         projectNameNoUnderscore = ''.join(elem.capitalize() for elem in projectName.split('_'))
         className = projectNameNoUnderscore + pipelineType.capitalize()
         classNameFotBaseObject = projectNameNoUnderscore + '_' + pipelineType
         data = data.replace('generatedClassName', classNameFotBaseObject)
         data = data.replace('generatedClass',className)
+        data = data.replace('generatedProjectName',projectNameNoUnderscore)
+        data = data.replace('generatedDirectory',directory)
         current_dir = directory + '/' + pipelineType
         if not os.path.exists(current_dir):
             os.mkdir(current_dir)
