@@ -20,7 +20,7 @@ setup(
         [console_scripts]
         ds-framework-cli=api_cli:cli
     ''',
-    version='0.1.4',
+    version='0.1.7',
     description='My first Python library',
     # url='http://pypi.python.org/pypi/PackageName/',
     author='oribrau@gmail.com',
@@ -32,12 +32,12 @@ setup(
 )
 
 # for test -  python setup.py pytest
-# for build wheel -  python setup.py bdist_wheel
-# for source dist -  python setup.py sdist
-# for build -  python setup.py build
-# for install -  python setup.py install
-# for uninstall - python -m pip uninstall ds_framework
-# for install - python -m pip install dist/ds_framework-0.1.0-py3-none-any.whl
+# for build wheel -  python setup-lib.py bdist_wheel
+# for source dist -  python setup-lib.py sdist
+# for build -  python setup-lib.py build
+# for install -  python setup-lib.py install
+# for uninstall - python -m pip uninstall dsframework
+# for install - python -m pip install dist/dsframework-0.1.0-py3-none-any.whl
 
 '''
     use
@@ -46,4 +46,12 @@ setup(
     3. twine check dist/*
     4. twine upload --repository-url https://pypi.org/legacy/ dist/*
     4. twine upload dist/*
+    
+    pip install dsframework --index-url https://pypi.org/simple
+    
+    how to use
+    
+    pip install dsframework
+    
+    ds-framework-cli generate project my-new-model
 '''
